# wasc

[![PyPI - Version](https://img.shields.io/pypi/v/wasc.svg)](https://pypi.org/project/wasc)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/wasc.svg)](https://pypi.org/project/wasc)

-----

**Table of Contents**

- [wasc](#wasc)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install wasc
```

## License

`wasc` is distributed under the terms of the [CECILL-2.1](https://spdx.org/licenses/CECILL-2.1.html) license.
